@@ -20,6 +20,12 @@ FAILEDOPERATION = 'FailedOperation'
 # The permission group has been bound.
 FAILEDOPERATION_ACCESSGROUPBOUND = 'FailedOperation.AccessGroupBound'
 
+# 
+FAILEDOPERATION_ACCOUNTINSUFFICIENTBALANCE = 'FailedOperation.AccountInsufficientBalance'
+
+# 
+FAILEDOPERATION_ACCOUNTUNAUTHENTICATED = 'FailedOperation.AccountUnauthenticated'
+
 # The file system is not empty.
 FAILEDOPERATION_FILESYSTEMNOTEMPTY = 'FailedOperation.FileSystemNotEmpty'
 
@@ -71,9 +77,6 @@ LIMITEXCEEDED = 'LimitExceeded'
 # Missing parameter.
 MISSINGPARAMETER = 'MissingParameter'
 
-# The operation was denied.
-OPERATIONDENIED = 'OperationDenied'
-
 # The resource is in use.
 RESOURCEINUSE = 'ResourceInUse'
 
